@@ -18,12 +18,18 @@ namespace FSpot {
 			this.SizeAllocated += HandleSizeAllocated;
 			this.KeyPressEvent += HandleKeyPressEvent;
 			this.ScrollEvent += HandleScrollEvent;
-			query.ItemChanged += HandleQueryItemChanged;
+			query.ItemsChanged += HandleQueryItemsChanged;
 			this.item = new BrowsablePointer (query, -1);
 			item.IndexChanged += PhotoIndexChanged;
 			this.Destroyed += HandleDestroyed;
+			this.SetTransparentColor (this.Style.BaseColors [(int)Gtk.StateType.Normal]);
 		}
 		
+		protected override void OnStyleSet (Gtk.Style previous)
+		{
+			this.SetTransparentColor (this.Style.Backgrounds [(int)Gtk.StateType.Normal]);
+		}
+
 		new public BrowsablePointer Item {
 			get {
 				return item;
@@ -39,12 +45,12 @@ namespace FSpot {
 			set {
 				if (query != null) {
 					query.Changed -= HandleQueryChanged;
-					query.ItemChanged -= HandleQueryItemChanged;
+					query.ItemsChanged -= HandleQueryItemsChanged;
 				}
 
 				query = value;
 				query.Changed += HandleQueryChanged;
-				query.ItemChanged += HandleQueryItemChanged;
+				query.ItemsChanged += HandleQueryItemsChanged;
 			}
 #endif
 		}
@@ -71,10 +77,12 @@ namespace FSpot {
 		}
 		*/
 
-		public void HandleQueryItemChanged (IBrowsableCollection browsable, int item)
+		public void HandleQueryItemsChanged (IBrowsableCollection browsable, BrowsableArgs args)
 		{
-			if (item == Item.Index)
-				Reload ();
+			foreach (int item in args.Items) {
+				if (item == Item.Index)
+					Reload ();
+			}
 		}
 
 		// Display.
@@ -156,6 +164,9 @@ namespace FSpot {
 				this.ZoomFit ();
 			} else {
 				this.Pixbuf = loader.Pixbuf;
+
+				if (!loader.Prepared)
+					this.ZoomFit ();
 			}
 
 			if (prev != this.Pixbuf && prev != null)
@@ -289,30 +300,44 @@ namespace FSpot {
 			switch (args.Event.Key) {
 			case Gdk.Key.Page_Up:
 			case Gdk.Key.KP_Page_Up:
+			case Gdk.Key.Up:
+			case Gdk.Key.KP_Up:
+			case Gdk.Key.Left:
+			case Gdk.Key.KP_Left:
 				this.Item.MovePrevious ();
 				break;
 			case Gdk.Key.Home:
+			case Gdk.Key.KP_Home:
 				this.Item.Index = 0;
 				break;
 			case Gdk.Key.End:
+			case Gdk.Key.KP_End:
 				this.Item.Index = this.Query.Count - 1;
 				break;
-			case Gdk.Key.space:
 			case Gdk.Key.Page_Down:
 			case Gdk.Key.KP_Page_Down:
+			case Gdk.Key.Down:
+			case Gdk.Key.KP_Down:
+			case Gdk.Key.Right:
+			case Gdk.Key.KP_Right:
+			case Gdk.Key.space:
+			case Gdk.Key.KP_Space:
 				this.Item.MoveNext ();
 				break;
 			case Gdk.Key.Key_0:
+			case Gdk.Key.KP_0:
 				this.Fit = true;
 				break;
 			case Gdk.Key.Key_1:
+			case Gdk.Key.KP_1:
 				this.Zoom =  1.0;
 				break;
 			case Gdk.Key.Key_2:
+			case Gdk.Key.KP_2:
 				this.Zoom = 2.0;
 				break;
-			case Gdk.Key.KP_Subtract:
 			case Gdk.Key.minus:
+			case Gdk.Key.KP_Subtract:
 				this.Zoom /= ZoomMultipler;
 				break;
 			case Gdk.Key.plus:
