@@ -3,6 +3,7 @@ using GLib;
 using Gtk;
 using GtkSharp;
 using System;
+using FSpot.Xmp;
 
 public class PhotoView : EventBox {
 	FSpot.Delay description_delay; 
@@ -175,6 +176,11 @@ public class PhotoView : EventBox {
 			description_entry.Sensitive = false;
 			description_entry.Text = "";
 		}
+		if (description_entry.Text == "")
+			tips.SetTip (description_entry, description_entry.Text, "This is a tip");
+		else
+			tips.SetTip (description_entry, null, "This is a tip");
+
 		description_entry.Changed += HandleDescriptionChanged;
 	}    
 
@@ -229,7 +235,7 @@ public class PhotoView : EventBox {
 		int x, y, width, height;
 		if (! photo_view.GetSelection (out x, out y, out width, out height)) {
 			string msg = Mono.Posix.Catalog.GetString ("No selection available");
-			string desc = Mono.Posix.Catalog.GetString ("This tool requires an active selection. Please select a region of the image and try the operation again");
+			string desc = Mono.Posix.Catalog.GetString ("This tool requires an active selection. Please select a region of the photo and try the operation again");
 			
 			HigMessageDialog md = new HigMessageDialog ((Gtk.Window)this.Toplevel, DialogFlags.DestroyWithParent, 
 								    Gtk.MessageType.Error, ButtonsType.Ok, 
@@ -247,15 +253,12 @@ public class PhotoView : EventBox {
 		}
 
 		Photo photo = (Photo)Item.Current;
-		Exif.ExifData exif_data = new Exif.ExifData (photo.DefaultVersionPath);
 
 		Pixbuf edited;
 		if (redeye) {
 			Gdk.Rectangle area = new Gdk.Rectangle (x, y, width, height);
 			edited = PixbufUtils.RemoveRedeye (original_pixbuf, 
 							   area);
-
-
 		} else { // Crop (I told you it was ugly)
 			edited = new Pixbuf (original_pixbuf.Colorspace, 
 					     false, original_pixbuf.BitsPerSample,
@@ -269,26 +272,15 @@ public class PhotoView : EventBox {
 		// be fixed there.
 		photo_view.Pixbuf = edited;
 		photo_view.UnsetSelection ();
-		bool version = false;
 
 		try {
-			if (photo.DefaultVersionId == Photo.OriginalVersionId) {
-				photo.DefaultVersionId = photo.CreateDefaultModifiedVersion (photo.DefaultVersionId, false);
-				version = true;
-				PixbufUtils.SaveJpeg (edited, photo.DefaultVersionPath, 
-						      95, exif_data);
-				FSpot.ThumbnailGenerator.Create (photo.DefaultVersionPath).Dispose ();
-				query.Commit (Item.Index);
-			} else {
-				// FIXME we need to invalidate the thumbnail in the cache as well
-				PixbufUtils.SaveJpeg (edited, photo.DefaultVersionPath, 
-						      95, exif_data);
-				FSpot.ThumbnailGenerator.Create (photo.DefaultVersionPath).Dispose ();
-				query.MarkChanged (Item.Index);
-			}
+			bool create_version = photo.DefaultVersionId == Photo.OriginalVersionId;
+			photo.SaveVersion (edited, create_version);
+			query.Commit (Item.Index);
+			query.MarkChanged (Item.Index);
 		} catch (System.Exception e) {
 			string msg = Mono.Posix.Catalog.GetString ("Error editing photo");
-			string desc = String.Format (Mono.Posix.Catalog.GetString ("Received exception \"{0}\". Unable to save image {1}"),
+			string desc = String.Format (Mono.Posix.Catalog.GetString ("Received exception \"{0}\". Unable to save photo {1}"),
 						     e.Message, photo.Name);
 
 			HigMessageDialog md = new HigMessageDialog ((Gtk.Window)this.Toplevel, DialogFlags.DestroyWithParent, 
@@ -297,9 +289,6 @@ public class PhotoView : EventBox {
 								    desc);
 			md.Run ();
 			md.Destroy ();
-
-			if (version)
-				photo.DeleteVersion (photo.DefaultVersionId);
 		}
 		
 		photo_view.Fit = true;
@@ -320,13 +309,9 @@ public class PhotoView : EventBox {
 
 #if true // UPDATE_EXIF_DESCRIPTION
 			Photo photo = query.Photos [description_photo];
-			FSpot.ImageFile img = FSpot.ImageFile.Create (photo.DefaultVersionPath);
-			if (img is FSpot.JpegFile) {
-				FSpot.JpegFile jimg = img as FSpot.JpegFile;
-				jimg.Description = photo.Description;
-				jimg.SaveMetaData (photo.DefaultVersionPath);
-			}
-			//Query.Store.Commit (photo);
+
+			photo.WriteMetadataToImage ();
+
 			Query.Commit (description_photo);
 #else
 			Query.Commit (description_photo);
@@ -347,6 +332,7 @@ public class PhotoView : EventBox {
 			else
 				CommitPendingChanges ();
 
+		tips.SetTip (description_entry, description_entry.Text, "This is a tip");
 		description_photo = Item.Index;
 		description_delay.Start ();
 	}
@@ -481,9 +467,13 @@ public class PhotoView : EventBox {
 		UpdateButtonSensitivity ();
 
 		vbox.ShowAll ();
-		tips.SetTip (crop_button, Mono.Posix.Catalog.GetString ("Crop image to selected area"), "so is this one");
-		tips.SetTip (redeye_button, Mono.Posix.Catalog.GetString ("Remove redeye from selected area"), "this is one too");
-		tips.SetTip (color_button, Mono.Posix.Catalog.GetString ("Adjust the image colors"), "This is a tip");
+		tips.SetTip (crop_button, Mono.Posix.Catalog.GetString ("Crop photo to selected area"), "");
+		tips.SetTip (redeye_button, Mono.Posix.Catalog.GetString ("Remove redeye from selected area"), "");
+		tips.SetTip (color_button, Mono.Posix.Catalog.GetString ("Adjust the photo colors"), "");
+		tips.SetTip (constraints_option_menu, Mono.Posix.Catalog.GetString ("Constrain the aspect ratio of the selection"), "");
+		tips.SetTip (display_next_button, Mono.Posix.Catalog.GetString ("Next photo"), "");
+		tips.SetTip (display_previous_button, Mono.Posix.Catalog.GetString ("Previous photo"), "");
+
 	}
 
 }
