@@ -38,20 +38,15 @@ public class TagCommands {
 		private void PopulateCategoryOptionMenu ()
 		{
 			categories = new ArrayList ();
+			categories.Add (tag_store.RootCategory);
 			PopulateCategories (categories, tag_store.RootCategory);
 
 			Menu menu = new Menu ();
 
-			if (categories.Count == 0) {
-				MenuItem item = new MenuItem (Mono.Posix.Catalog.GetString ("(No categories)"));
-				category_option_menu.Sensitive = false;
-				menu.Append (item);
-			} else {
-				foreach (Category category in categories)
-					menu.Append (TagMenu.TagItem.IndentedItem (category));
+			foreach (Category category in categories)
+				menu.Append (TagMenu.TagItem.IndentedItem (category));
 
-				category_option_menu.Sensitive = true;
-			}
+			category_option_menu.Sensitive = true;
 
 			menu.ShowAll ();
 			category_option_menu.Menu = menu;
@@ -60,7 +55,7 @@ public class TagCommands {
 		private bool TagNameExistsInCategory (string name, Category category)
 		{
 			foreach (Tag tag in category.Children) {
-				if (tag.Name == name)
+				if (String.Compare(tag.Name, name, true) == 0)
 					return true;
 
 				if (tag is Category && TagNameExistsInCategory (name, tag as Category))
@@ -124,20 +119,13 @@ public class TagCommands {
 
 			this.Dialog.DefaultResponse = ResponseType.Ok;
 
-			switch (type) {
-			case TagType.Tag:
-				this.Dialog.Title = Mono.Posix.Catalog.GetString ("Create New Tag");
-				prompt_label.Text = Mono.Posix.Catalog.GetString ("Name of new tag:");
-				break;
-			case TagType.Category:
-				this.Dialog.Title = Mono.Posix.Catalog.GetString ("Create New Category");
-				prompt_label.Text = Mono.Posix.Catalog.GetString ("Name of new category:");
-				break;
-			}
+			this.Dialog.Title = Mono.Posix.Catalog.GetString ("Create New Tag");
+			prompt_label.Text = Mono.Posix.Catalog.GetString ("Name of new tag:");
 
 			PopulateCategoryOptionMenu ();
 			this.Category = default_category;
 			Update ();
+			tag_name_entry.GrabFocus ();
 
 			ResponseType response = (ResponseType) this.Dialog.Run ();
 
@@ -192,7 +180,7 @@ public class TagCommands {
 		private bool TagNameExistsInCategory (string name, Category category)
 		{
 			foreach (Tag tag in category.Children) {
-				if (tag.Name == name)
+				if (String.Compare(tag.Name, name, true) == 0)
 					return true;
 
 				if (tag is Category && TagNameExistsInCategory (name, tag as Category))
@@ -225,7 +213,7 @@ public class TagCommands {
 		private void PopulateCategories (ArrayList categories, Category parent)
 		{
 			foreach (Tag tag in parent.Children) {
-				if (tag is Category) {
+				if (tag is Category && tag != this.tag && !this.tag.IsAncestorOf (tag)) {
 					categories.Add (tag);
 					PopulateCategories (categories, tag as Category);
 				}
@@ -263,10 +251,7 @@ public class TagCommands {
 				     parent = parent.Category)
 					label_builder.Append ("  ");
 				
-				if (category == root)
-					label_builder.Append ("(Toplevel)");
-				else 
-					label_builder.Append (category.Name);
+				label_builder.Append (category.Name);
 				
 				// FIXME escape underscores.
 				MenuItem item = new MenuItem (label_builder.ToString ());
@@ -287,13 +272,8 @@ public class TagCommands {
 			tag = t;
 			this.Dialog.DefaultResponse = ResponseType.Ok;
 
-			if (t is Category) {
-				this.Dialog.Title = Mono.Posix.Catalog.GetString ("Edit Category");
-				prompt_label.Text = Mono.Posix.Catalog.GetString ("Category name:");
-			} else {
-				this.Dialog.Title = Mono.Posix.Catalog.GetString ("Edit Tag");
-				prompt_label.Text = Mono.Posix.Catalog.GetString ("Tag name:");
-			}
+			this.Dialog.Title = Mono.Posix.Catalog.GetString ("Edit Tag");
+			prompt_label.Text = Mono.Posix.Catalog.GetString ("Tag name:");
 
 			orig_name = last_valid_name = t.Name;
 			tag_name_entry.Text = t.Name;
@@ -303,6 +283,8 @@ public class TagCommands {
 			
 			icon_button.Clicked += HandleIconButtonClicked;
 			icon_button.SetSizeRequest (48, 48);
+			
+			tag_name_entry.GrabFocus ();
 
 			category_option_menu.Changed += HandleTagNameEntryChanged;
 			ResponseType response = (ResponseType) this.Dialog.Run ();
@@ -365,6 +347,9 @@ public class TagCommands {
 			Gdk.Pixbuf tmp = null;
 		       
 			image_view.GetSelection (out x, out y, out width, out height);
+			if (width > 0 && height > 0) 
+				icon_view.Selection.Clear ();
+				
 			if (image_view.Pixbuf != null) {
 				if (width > 0 && height > 0) {
 					tmp = new Gdk.Pixbuf (image_view.Pixbuf, x, y, width, height);
@@ -372,6 +357,8 @@ public class TagCommands {
 					preview_image.Pixbuf = PixbufUtils.TagIconFromPixbuf (tmp);
 					
 					tmp.Dispose ();
+				} else {
+					preview_image.Pixbuf = PixbufUtils.TagIconFromPixbuf (image_view.Pixbuf);
 				}
 			}
 		}
@@ -387,6 +374,7 @@ public class TagCommands {
 
 		public void HandleIconViewSelectionChanged (FSpot.IBrowsableCollection collection) 
 		{
+			// FIXME this handler seems to be called twice for each selection change
 			if (icon_view.Selection.Count > 0)
 			{
 				FSpot.IBrowsableItem item = icon_view.Selection [0];
@@ -405,11 +393,7 @@ public class TagCommands {
 		{
 			this.CreateDialog ("edit_icon_dialog");
 
-			if (t is Category) {
-				this.Dialog.Title = String.Format (Mono.Posix.Catalog.GetString ("Edit icon For category {0}"), t.Name);
-			} else {
-				this.Dialog.Title = String.Format (Mono.Posix.Catalog.GetString ("Edit icon for tag {0}"), t.Name);
-			}
+			this.Dialog.Title = String.Format (Mono.Posix.Catalog.GetString ("Edit Icon for Tag {0}"), t.Name);
 
 			preview_image.Pixbuf = t.Icon;
 
